"""

    STLDAPSyntax.py
    $Author: stevray $
    $Date: 2002/02/13 18:24:07 $

Copyright (C) 2002 Association of Universities for Research in
Astronomy (AURA).  See LICENSE.txt for the usual disclaimers.

       This module defines the valid LDAP attribute syntaxes and
       provides methods for converting between syntax OIDs and names.

"""

__version__ = '$Revision: 1.4 $'[11:-2]

_ldapSyntaxes = {
    '1.3.6.1.4.1.1466.115.121.1.5':       'Binary',
    '1.3.6.1.4.1.1466.115.121.1.7':       'Boolean',
    '1.3.6.1.4.1.1466.115.121.1.11':      'CountryString',
    '1.3.6.1.4.1.1466.115.121.1.12':      'DN',
    '1.3.6.1.4.1.1466.115.121.1.15':      'DirectoryString',
    '1.3.6.1.4.1.1466.115.121.1.24':      'GeneralizedTime',
    '1.3.6.1.4.1.1466.115.121.1.26':      'IA5String',
    '1.3.6.1.4.1.1466.115.121.1.27':      'INTEGER',
    '1.3.6.1.4.1.1466.115.121.1.40':      'OctetString',
    '1.3.6.1.4.1.1466.115.121.1.40{128}': 'Password',
    '1.3.6.1.4.1.1466.115.121.1.41':      'PostalAddress',
    '1.3.6.1.4.1.1466.115.121.1.50':      'TelephoneNumber',
    '1.3.6.1.4.1.4401.1.1.1':             'URI',
    }

def isValidOID(value):
    if _ldapSyntaxes.has_key(value):
        return 1
    else:
        return 0

def getNameFromOID(OID):
    """ Returns the syntax name for a given OID. """
    
    assert isValidOID(OID)
    return _ldapSyntaxes[OID]        

def getOIDFromName(Name):
    """ Returns the OID for the named syntax. """

    tmp = [OID for OID in _ldapSyntaxes.keys()
           if _ldapSyntaxes[OID].lower() == Name.lower()]

    assert len(tmp) == 1
    return tmp[0]

def getCanonicalName(Name):
    """ Returns the canonical name of the syntax with
        propert attention to case. """
    
    return getNameFromOID(getOIDFromName(Name))

    